'use strict';

module.exports = function (t) {
  return function isReactClass(path) {
    var superClass = path.node.superClass;

    var isDirectReactClass = t.isMemberExpression(superClass) && t.isIdentifier(superClass.object, { name: 'React' }) && (t.isIdentifier(superClass.property, { name: 'Component' }) || t.isIdentifier(superClass.property, { name: 'PureComponent' }));

    if (isDirectReactClass) {
      return true;
    }

    var state = {
      localComponentNames: []
    };
    var importVisitor = {
      ImportDeclaration: function ImportDeclaration(nestedPath) {
        var node = nestedPath.node;

        if (t.isStringLiteral(node.source, { value: 'react' })) {
          this.localComponentNames = node.specifiers.filter(function (specifier) {
            return t.isImportSpecifier(specifier) && (specifier.imported.name === 'Component' || specifier.imported.name === 'PureComponent');
          }).map(function (specifier) {
            return specifier.local.name;
          });
        }
      }
    };

    // Check for imports as local variable names
    path.findParent(function (p) {
      return t.isProgram(p);
    }).traverse(importVisitor, state);
    if (state.localComponentNames.length === 0) {
      return false;
    }
    return state.localComponentNames.indexOf(superClass.name) !== -1;
  };
};